@@ -31,6 +31,7 @@ __all__ = [
     'pixel_coords_to_telescope',
     'radial_light_distribution',
     'tag_pix_thr',
+    'update_parameters',
 ]
 
 
@@ -59,6 +60,47 @@ def pixel_coords_to_telescope(geom, equivalent_focal_length):
     return tel_coord.fov_lon, tel_coord.fov_lat
 
 
+def update_parameters(config, n_pixels):
+    """
+    Create the parameters used to select good muon rings and perform the muon analysis.
+
+    Parameters
+    ----------
+    config: `dict` or None
+        Subset of parameters to be updated
+    n_pixels: `int`
+        Number of pixels of the camera
+
+    Returns
+    -------
+    params: `dict`
+        Dictionary of parameters used for the muon analysis
+
+    """
+    params = {
+        'tailcuts': [10, 5],  # Thresholds used for the tail_cut cleaning
+        'min_pix': 0.08,  # minimum fraction of the number of pixels in the ring with >0 signal
+        'min_pix_fraction_after_cleaning': 0.1,  # minimum fraction of the ring pixels that must be above tailcuts[0]
+        'min_ring_radius': 0.8 * u.deg,  # minimum ring radius
+        'max_ring_radius': 1.5 * u.deg,  # maximum ring radius
+        'max_radial_stdev': 0.1 * u.deg,  # maximum standard deviation of the light distribution along ring radius
+        'max_radial_excess_kurtosis': 1.,  # maximum excess kurtosis
+        'min_impact_parameter': 0.2,  # in fraction of mirror radius
+        'max_impact_parameter': 0.9,  # in fraction of mirror radius
+        'ring_integration_width': 0.25,  # +/- integration range along ring radius,
+                                         # in fraction of ring radius (was 0.4 until 20200326)
+        'outer_ring_width': 0.2,  # in fraction of ring radius, width of ring just outside the
+                                  # integrated muon ring, used to check pedestal bias
+        'ring_completeness_threshold': 30,  # Threshold in p.e. for pixels used in the ring completeness estimation
+    }
+    if config is not None:
+        for key in config.keys():
+            params[key] = config[key]
+    params['min_pix'] = int(n_pixels * params['min_pix'])
+
+    return params
+
+
 def fit_muon(x, y, image, geom, tailcuts):
     """
     Fit the muon ring
@@ -114,23 +156,22 @@ def fit_muon(x, y, image, geom, tailcuts):
     return ring, clean_mask, dist, image_clean
 
 
-def analyze_muon_event(subarray, event_id, image, geom, equivalent_focal_length,
-                       mirror_area, plot_rings, plots_path):
+def analyze_muon_event(subarray, tel_id, event_id, image, good_ring_config, plot_rings, plots_path):
     """
     Analyze an event to fit a muon ring
 
     Parameters
     ----------
+    subarray: `ctapipe.instrument.subarray.SubarrayDescription`
+        Telescopes subarray
+    tel_id : `int`
+        Id of the telescope used
     event_id : `int`
         Id of the analyzed event
     image : `np.ndarray`
         Number of photoelectrons in each pixel
-    geom :  `ctapipe.instrument.CameraGeometry`
-        Camera geometry
-    equivalent_focal_length : `float`
-        Focal length of the telescope
-    mirror_area : `float`
-        Mirror area of the telescope in square meters
+    good_ring_config : `dict` or None
+        Set of parameters used to identify good muon rings to update LST-1 defaults
     plot_rings : `bool`
         Plot the muon ring
     plots_path : `string`
@@ -144,9 +185,9 @@ def analyze_muon_event(subarray, event_id, image, geom, equivalent_focal_length,
     ring_size : `float`
         Total intensity in ring in photoelectrons
     size_outside_ring : `float`
-        Intensity outside the muon ting in photoelectrons
+        Intensity outside the muon ring in photoelectrons
         to check for "shower contamination"
-    muonringparam : `MuonParametersContainer`
+    muonringparam : `MuonRingContainer`
     good_ring : `bool`
         It determines whether the ring can be used for analysis or not
     radial_distribution : `dict`
@@ -155,36 +196,26 @@ def analyze_muon_event(subarray, event_id, image, geom, equivalent_focal_length,
         Charge "just outside" ring, to check the possible signal extractor bias
     muonparameters : `MuonParametersContainer`
     """
-    # TODO: Several hard-coded quantities that can go into a configuration file
 
-    lst1_tel_id = 1
-    lst1_description = subarray.tels[lst1_tel_id]
-
-    tailcuts = [10, 5]
+    tel_description = subarray.tels[tel_id]
 
     cam_rad = (
-                      lst1_description.camera.geometry.guess_radius() / lst1_description.optics.equivalent_focal_length
+                      tel_description.camera.geometry.guess_radius() / tel_description.optics.equivalent_focal_length
               ) * u.rad
+    geom = tel_description.camera.geometry
+    equivalent_focal_length = tel_description.optics.equivalent_focal_length
+    mirror_area = tel_description.optics.mirror_area
 
-    # some cuts for good ring selection:
-    min_pix = 148  # (8%) minimum number of pixels in the ring with >0 signal
-    min_pix_fraction_after_cleaning = 0.1  # minimum fraction of the ring pixels that must be above tailcuts[0]
-    min_ring_radius = 0.8 * u.deg  # minimum ring radius
-    max_ring_radius = 1.5 * u.deg  # maximum ring radius
-    max_radial_stdev = 0.1 * u.deg  # maximum standard deviation of the light distribution along ring radius
-    max_radial_excess_kurtosis = 1.  # maximum excess kurtosis
-    min_impact_parameter = 0.2  # in fraction of mirror radius
-    max_impact_parameter = 0.9  # in fraction of mirror radius
-    ring_integration_width = 0.25  # +/- integration range along ring radius, in fraction of ring radius (was 0.4 until 20200326)
-    outer_ring_width = 0.2  # in fraction of ring radius, width of ring just outside the integrated muon ring, used to check pedestal bias
+    # some parameters for analysis and cuts for good ring selection:
+    params = update_parameters(good_ring_config, geom.n_pixels)
 
     x, y = pixel_coords_to_telescope(geom, equivalent_focal_length)
     muonringparam, clean_mask, dist, image_clean = fit_muon(x, y, image, geom,
-                                                            tailcuts)
+                                                            params['tailcuts'])
 
     mirror_radius = np.sqrt(mirror_area / np.pi)  # meters
     dist_mask = np.abs(dist - muonringparam.radius
-                       ) < muonringparam.radius * ring_integration_width
+                       ) < muonringparam.radius * params['ring_integration_width']
     pix_ring = image * dist_mask
     pix_outside_ring = image * ~dist_mask
 
@@ -192,7 +223,7 @@ def analyze_muon_event(subarray, event_id, image, geom, equivalent_focal_length,
     dist_mask_2 = np.logical_and(~dist_mask,
                                  np.abs(dist - muonringparam.radius) <
                                  muonringparam.radius *
-                                 (ring_integration_width + outer_ring_width))
+                                 (params['ring_integration_width'] + params['outer_ring_width']))
     pix_ring_2 = image[dist_mask_2]
 
     #    nom_dist = np.sqrt(np.power(muonringparam.center_x,2)
@@ -211,13 +242,13 @@ def analyze_muon_event(subarray, event_id, image, geom, equivalent_focal_length,
 
     # Do complicated calculations (minuit-based max likelihood ring fit) only for selected rings:
     candidate_clean_ring = all(
-        [radial_distribution['standard_dev'] < max_radial_stdev,
-         radial_distribution['excess_kurtosis'] < max_radial_excess_kurtosis,
-         (pix_ring > tailcuts[0]).sum() >
-         min_pix_fraction_after_cleaning * min_pix,
-         np.count_nonzero(pix_ring) > min_pix,
-         muonringparam.radius < max_ring_radius,
-         muonringparam.radius > min_ring_radius
+        [radial_distribution['standard_dev'] < params['max_radial_stdev'],
+         radial_distribution['excess_kurtosis'] < params['max_radial_excess_kurtosis'],
+         (pix_ring > params['tailcuts'][0]).sum() >
+         params['min_pix_fraction_after_cleaning'] * params['min_pix'],
+         np.count_nonzero(pix_ring) > params['min_pix'],
+         muonringparam.radius < params['max_ring_radius'],
+         muonringparam.radius > params['min_ring_radius']
          ])
 
     if candidate_clean_ring:
@@ -228,7 +259,7 @@ def analyze_muon_event(subarray, event_id, image, geom, equivalent_focal_length,
         pedestal_stddev = 1.1 * np.ones(len(image))
 
         muonintensityoutput = \
-            intensity_fitter(1,
+            intensity_fitter(tel_id,
                              muonringparam.center_x,
                              muonringparam.center_y,
                              muonringparam.radius,
@@ -247,7 +278,7 @@ def analyze_muon_event(subarray, event_id, image, geom, equivalent_focal_length,
             muonringparam.radius,
             muonringparam.center_x,
             muonringparam.center_y,
-            threshold=30,
+            threshold=params['ring_completeness_threshold'],
             bins=30)
 
         # No longer existing in ctapipe 0.8:
@@ -281,8 +312,8 @@ def analyze_muon_event(subarray, event_id, image, geom, equivalent_focal_length,
     # Now add the conditions based on the detailed muon ring fit:
     conditions = [
         candidate_clean_ring,
-        muonintensityoutput.impact < max_impact_parameter * mirror_radius,
-        muonintensityoutput.impact > min_impact_parameter * mirror_radius,
+        muonintensityoutput.impact < params['max_impact_parameter'] * mirror_radius,
+        muonintensityoutput.impact > params['min_impact_parameter'] * mirror_radius,
 
         # TODO: To be applied when we have decent optics.
         # muonintensityoutput.width
